smartcard.sw.SWExceptions

# ``smartcard`.`sw`.`SWExceptions``

module documentation

Status Word (SW) Exceptions

This module defines the exceptions raised by status word errors or warnings.

__author__ = "http://www.gemalto.com"

Copyright 2001-2012 gemalto Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com

This file is part of pyscard.

pyscard is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

pyscard is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with pyscard; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Exception | `CheckingErrorException` | Raised when a checking error is detected from sw1, sw2. Examples of checking error: sw1=67 to 6F (ISO781604).
Exception | `ExecutionErrorException` | Raised when an execution error is detected from sw1, sw2. Examples of execution error: sw1=64 or sw=65 (ISO7816-4).
Exception | `SecurityRelatedException` | Raised when a security issue is detected from sw1, sw2. Examples of security issue: sw1=66 (ISO7816-4).
Exception | `SWException` | Base class for status word exceptions.
Exception | `WarningProcessingException` | Raised when a warning processing is detected from sw1, sw2. Examples of warning processing exception: sw1=62 or sw=63 (ISO7816-4).